@@ -69,15 +69,14 @@ setMethod("dist_pdf",
           definition = function(m, q=NULL, log=FALSE) {
             xmin = m$getXmin(); pars = m$getPars()
             
-            if(is.null(q)) {
-              q = m$dat
-              n = m$internal[["n"]]; N = length(q)
-              q = q[(N-n+1):N]
-            } else {
-              q[q >= m$xmin]
-            }
+            if(is.null(q)) q = m$dat
             pdf = dexp(q, pars, log=TRUE) - pexp(xmin, pars, lower.tail=FALSE, log.p=TRUE)
-            if(!log) pdf = exp(pdf)
+            if(!log) {
+              pdf = exp(pdf)
+              pdf[q < xmin] = 0
+            } else {
+              pdf[q < xmin] = -Inf
+            }
             pdf
           }
 )
@@ -92,21 +91,19 @@ setMethod("dist_cdf",
           definition = function(m, q=NULL, lower_tail=TRUE) {
             pars = m$pars; xmin = m$xmin
             if(is.null(pars)) stop("Model parameters not set.")  
-            if(is.null(q)) {
-              q = m$dat
-              n = m$internal[["n"]]; N = length(q)
-              q = q[(N-n+1):N]
-            } 
+            if(is.null(q)) q = m$dat
 
             if(lower_tail) {
               p = pexp(q, pars, lower.tail=lower_tail) 
               C = pexp(xmin, pars, lower.tail=FALSE) 
-              (p/C-1/C+1)
+              cdf = (p/C-1/C+1)
             } else {
               log_p = pexp(q, pars, lower.tail=FALSE, log.p=TRUE) 
               log_C = pexp(xmin, pars, lower.tail=FALSE, log.p=TRUE)
-              exp(log_p - log_C)
+              cdf = exp(log_p - log_C)
             }
+            cdf[q < xmin] = 0
+            cdf
           }
 )
 
@@ -121,10 +118,6 @@ setMethod("dist_all_cdf",
           }
 )
 
-
-
-
-
 #############################################################
 #ll method
 #############################################################
@@ -170,10 +163,7 @@ setMethod("dist_rand",
             u = runif(n, 0, exp(-m$pars*m$xmin))
             -log(u)/m$pars
           }
-)
-            
-            
-
+)  
 
 #############################################################
 #MLE method
