@@ -162,6 +162,16 @@ pois_tail_ll = function(x, rate, xmin) {
 ########################################################
 #Rand number generator
 ########################################################
+# Adapted from https://stat.ethz.ch/pipermail/r-help/2005-May/070680.html
+#' @rdname dist_rand-methods
+#' @aliases dist_rand,dispois-method
+setMethod("dist_rand",
+          signature = signature(m="dispois"),
+          definition = function(m, n="numeric") {
+            xmin = m$xmin; lambda = m$pars
+            qpois(runif(n, ppois(xmin-1, lambda, lower.tail=T), 1), lambda)
+          }
+)
 
 
 #############################################################
